@@ -874,7 +874,7 @@ chordDiagramFromDataFrame = function(df, grid.col = NULL, grid.border = NA, tran
 	}
 
 	for(k in seq_len(nrow(df))) {
-		if (df$value[k]/sum(df$value) < 1e-6) next
+		if (abs(df$value[k])/sum(abs(df$value)) < 1e-6) next
 
 		if(setequal(direction.type, c("diffHeight"))) {
 			circos.link(df$rn[k], c(df$x1[k] - abs(df$value[k]), df$x1[k]),
